:man_page: mongoc_apm_topology_opening_t

mongoc_apm_topology_opening_t
=============================

Topology-opening event

Synopsis
--------

An event notification sent when the driver initializes a :symbol:`mongoc_topology_description_t`.

.. seealso::

  | :doc:`Introduction to Application Performance Monitoring <application-performance-monitoring>`

.. only:: html

  Functions
  ---------

  .. toctree::
    :titlesonly:
    :maxdepth: 1

    mongoc_apm_topology_opening_get_context
    mongoc_apm_topology_opening_get_topology_id

